package initialize

import (
	_ "gin-vue-admin/docs"
	"gin-vue-admin/global"
	"gin-vue-admin/middleware"
	"gin-vue-admin/router"
	"net/http"

	"github.com/gin-gonic/gin"
	"github.com/swaggo/gin-swagger"
	"github.com/swaggo/gin-swagger/swaggerFiles"
)

// 初始化总路由

func Routers() *gin.Engine {
	var Router = gin.Default()
	Router.StaticFS(global.GVA_CONFIG.Local.Path, http.Dir(global.GVA_CONFIG.Local.Path)) // 为用户头像和文件提供静态地址
	// Router.Use(middleware.LoadTls())  // 打开就能玩https了
	global.GVA_LOG.Info("use middleware logger")
	// 跨域
	//Router.Use(middleware.Cors()) // 如需跨域可以打开
	global.GVA_LOG.Info("use middleware cors")
	Router.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))
	global.GVA_LOG.Info("register swagger handler")
	// 方便统一添加路由组前缀 多服务器上线使用
	PublicGroup := Router.Group("")
	{
		router.RouterApp.System.InitBaseRouter(PublicGroup) // 注册基础功能路由 不做鉴权
		router.RouterApp.System.InitInitRouter(PublicGroup) // 自动初始化相关
	}
	PrivateGroup := Router.Group("")
	PrivateGroup.Use(middleware.JWTAuth()).Use(middleware.CasbinHandler())
	{
		router.RouterApp.System.InitApiRouter(PrivateGroup)                    // 注册功能api路由
		router.RouterApp.System.InitJwtRouter(PrivateGroup)                    // jwt相关路由
		router.RouterApp.System.InitUserRouter(PrivateGroup)                   // 注册用户路由
		router.RouterApp.System.InitMenuRouter(PrivateGroup)                   // 注册menu路由
		router.RouterApp.System.InitEmailRouter(PrivateGroup)                  // 邮件相关路由
		router.RouterApp.System.InitSystemRouter(PrivateGroup)                 // system相关路由
		router.RouterApp.System.InitCasbinRouter(PrivateGroup)                 // 权限相关路由
		router.RouterApp.Example.InitCustomerRouter(PrivateGroup)              // 客户路由
		router.RouterApp.System.InitAutoCodeRouter(PrivateGroup)               // 创建自动化代码
		router.RouterApp.System.InitAuthorityRouter(PrivateGroup)              // 注册角色路由
		router.RouterApp.Example.InitSimpleUploaderRouter(PrivateGroup)        // 断点续传（插件版）
		router.RouterApp.System.InitSysDictionaryRouter(PrivateGroup)          // 字典管理
		router.RouterApp.System.InitSysOperationRecordRouter(PrivateGroup)     // 操作记录
		router.RouterApp.System.InitSysDictionaryDetailRouter(PrivateGroup)    // 字典详情管理
		router.RouterApp.Example.InitFileUploadAndDownloadRouter(PrivateGroup) // 文件上传下载功能路由
		router.RouterApp.Example.InitExcelRouter(PrivateGroup)                 // 表格导入导出

		// Code generated by gin-vue-admin Begin; DO NOT EDIT.
		// Code generated by gin-vue-admin End; DO NOT EDIT.
	}
	global.GVA_LOG.Info("router register success")
	return Router
}
